==> schlix-cms-v2.2.2-1.zip: schlix/system/themes/beritanews/header.inc.php <==
<?php
if (!defined('SCHLIX_VERSION')) die('No Access'); // this protection line must exist in all template files
/**
 * beritanews - theme for SCHLIX CMS
 *
 * You can modify this theme as the license is MIT, not SCHLIX Shared Source
 *  
 * @copyright 2020 SCHLIX Web Inc
 * @license MIT
 * @version 1.0
 * @link    https://www.schlix.com
 */

/********* MUST DECLARE SCHLIX_THEME_SKIN, DO NOT DELETE! ***********/
define('SCHLIX_THEME_SKIN','bootstrap4');

global $HTMLHeader;

?>
<meta name="viewport" content="width=device-width, initial-scale=1.0">
<link rel="stylesheet" type="text/css" href="<?= SCHLIX_SYSTEM_URL_PATH ?>/fonts/roboto/roboto.css" />
<link rel="stylesheet" type="text/css" href="<?= SCHLIX_SYSTEM_URL_PATH ?>/fonts/alegreya/alegreya.css" />
<link rel="stylesheet" type="text/css" href="<?= SCHLIX_SYSTEM_URL_PATH ?>/fonts/font-awesome/font-awesome.min.css" />
<link rel="stylesheet" type="text/css" href="<?= CURRENT_THEME_URL_PATH; ?>/css/bootstrap.min.css" />
<link rel="stylesheet" type="text/css" href="<?= CURRENT_THEME_URL_PATH; ?>/css/style.css" />
<meta name="description" content="<?= \SCHLIX\cmsPageOutput::HTMLMetaDescription() ?>" />
<meta name="keywords" content="<?= \SCHLIX\cmsPageOutput::HTMLMetaKeywords()  ?>" />
<!--[if IE]>
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
<![endif]-->

<link rel="apple-touch-icon" sizes="57x57" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-touch-icon-57x57.png" />
<link rel="apple-touch-icon" sizes="72x72" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-touch-icon-72x72.png" />
<link rel="apple-touch-icon" sizes="76x76" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-touch-icon-76x76.png" />
<link rel="apple-touch-icon" sizes="114x114" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-touch-icon-114x114.png" />
<link rel="apple-touch-icon" sizes="120x120" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-touch-icon-120x120.png" />
<link rel="apple-touch-icon" sizes="144x144" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-touch-icon-144x144.png" />
<link rel="apple-touch-icon" sizes="152x152" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-touch-icon-152x152.png" />
<link rel="apple-touch-icon" sizes="180x180" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-touch-icon-180x180.png" />
<!-- regular favicon -->
<link rel="shortcut icon" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/favicon.ico" type="image/x-icon" />
<link rel="icon" type="image/png" sizes="32x32" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/favicon-32x32.png">
<link rel="icon" type="image/png" sizes="96x96" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/favicon-96x96.png">
<link rel="icon" type="image/png" sizes="16x16" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/favicon-16x16.png">
<link rel="apple-touch-icon" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon.png" />
<!-- Apple favicon -->
<link rel="apple-touch-icon" sizes="57x57" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-57x57.png">
<link rel="apple-touch-icon" sizes="60x60" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-60x60.png">
<link rel="apple-touch-icon" sizes="72x72" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-72x72.png">
<link rel="apple-touch-icon" sizes="76x76" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-76x76.png">
<link rel="apple-touch-icon" sizes="114x114" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-114x114.png">
<link rel="apple-touch-icon" sizes="120x120" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-120x120.png">
<link rel="apple-touch-icon" sizes="144x144" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-144x144.png">
<link rel="apple-touch-icon" sizes="152x152" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-152x152.png">
<link rel="apple-touch-icon" sizes="180x180" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-180x180.png">
<!-- Amdroid favicon -->
<link rel="icon" type="image/png" sizes="96x96"  href="<?= CURRENT_THEME_URL_PATH; ?>/icons/android-icon-96x96.png">
<link rel="icon" type="image/png" sizes="144x144"  href="<?= CURRENT_THEME_URL_PATH; ?>/icons/android-icon-144x144.png">
<link rel="icon" type="image/png" sizes="192x192"  href="<?= CURRENT_THEME_URL_PATH; ?>/icons/android-icon-192x192.png">
<link rel="manifest" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/manifest.json">
<meta name="theme-color" content="#ffffff">

<!-- Blog RSS and JSON Feed -->
<link rel="alternate" type="application/rss+xml" title="<?= ___h(SCHLIX_SITE_NAME) ?> &raquo; RSS Feed" href="<?= SCHLIX_SITE_HTTP_URL.SCHLIX_SITE_HTTPBASE.'/'.get_application_alias('blog').'/rss' ?>" />
<link rel="alternate" type="application/json" title="<?= ___h(SCHLIX_SITE_NAME) ?> &raquo; JSON Feed" href="<?= SCHLIX_SITE_HTTP_URL.SCHLIX_SITE_HTTPBASE.'/'.get_application_alias('blog').'/jsonfeed' ?>" />
<!-- A9 OpenSearch -->
<link type="application/opensearchdescription+xml" rel="search" href="<?= SCHLIX_SITE_HTTP_URL.SCHLIX_SITE_HTTPBASE.'/'.get_application_alias('search').'/opensearchxml' ?>"/>

<?php /* Note: if you must include the Javascript at the top, use \SCHLIX\cmsPageOutput::HTMLHeader(); in header.inc.php and remove the \SCHLIX\cmsPageOutput::HTMLFooterScripts(); in footer.inc.php, and move all the contents of footer.inc.php to header.inc.php */ ?>
<?= \SCHLIX\cmsPageOutput::HTMLHeaderNonScripts(); ?>

==> schlix-cms-v2.2.7-1.zip: schlix/system/themes/beritanews/header.inc.php <==
<?php
if (!defined('SCHLIX_VERSION')) die('No Access'); // this protection line must exist in all template files
/**
 * beritanews - theme for SCHLIX CMS
 *
 * You can modify this theme as the license is MIT, not SCHLIX Shared Source
 *  
 * @copyright 2020 SCHLIX Web Inc
 * @license MIT
 * @version 1.0
 * @link    https://www.schlix.com
 */

/********* MUST DECLARE SCHLIX_THEME_SKIN, DO NOT DELETE! ***********/
if (!defined ('SCHLIX_THEME_SKIN')) define('SCHLIX_THEME_SKIN','bootstrap4');

global $HTMLHeader;

?>
<meta name="viewport" content="width=device-width, initial-scale=1.0">
<link rel="stylesheet" type="text/css" href="<?= SCHLIX_SYSTEM_URL_PATH ?>/fonts/roboto/roboto.css" />
<link rel="stylesheet" type="text/css" href="<?= SCHLIX_SYSTEM_URL_PATH ?>/fonts/alegreya/alegreya.css" />
<link rel="stylesheet" type="text/css" href="<?= SCHLIX_SYSTEM_URL_PATH ?>/fonts/font-awesome/font-awesome.min.css" />
<link rel="stylesheet" type="text/css" href="<?= CURRENT_THEME_URL_PATH; ?>/css/bootstrap.min.css" />
<link rel="stylesheet" type="text/css" href="<?= CURRENT_THEME_URL_PATH; ?>/css/style.css" />
<meta name="description" content="<?= \SCHLIX\cmsPageOutput::HTMLMetaDescription() ?>" />
<meta name="keywords" content="<?= \SCHLIX\cmsPageOutput::HTMLMetaKeywords()  ?>" />
<!--[if IE]>
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
<![endif]-->

<link rel="apple-touch-icon" sizes="57x57" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-touch-icon-57x57.png" />
<link rel="apple-touch-icon" sizes="72x72" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-touch-icon-72x72.png" />
<link rel="apple-touch-icon" sizes="76x76" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-touch-icon-76x76.png" />
<link rel="apple-touch-icon" sizes="114x114" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-touch-icon-114x114.png" />
<link rel="apple-touch-icon" sizes="120x120" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-touch-icon-120x120.png" />
<link rel="apple-touch-icon" sizes="144x144" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-touch-icon-144x144.png" />
<link rel="apple-touch-icon" sizes="152x152" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-touch-icon-152x152.png" />
<link rel="apple-touch-icon" sizes="180x180" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-touch-icon-180x180.png" />
<!-- regular favicon -->
<link rel="shortcut icon" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/favicon.ico" type="image/x-icon" />
<link rel="icon" type="image/png" sizes="32x32" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/favicon-32x32.png">
<link rel="icon" type="image/png" sizes="96x96" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/favicon-96x96.png">
<link rel="icon" type="image/png" sizes="16x16" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/favicon-16x16.png">
<link rel="apple-touch-icon" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon.png" />
<!-- Apple favicon -->
<link rel="apple-touch-icon" sizes="57x57" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-57x57.png">
<link rel="apple-touch-icon" sizes="60x60" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-60x60.png">
<link rel="apple-touch-icon" sizes="72x72" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-72x72.png">
<link rel="apple-touch-icon" sizes="76x76" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-76x76.png">
<link rel="apple-touch-icon" sizes="114x114" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-114x114.png">
<link rel="apple-touch-icon" sizes="120x120" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-120x120.png">
<link rel="apple-touch-icon" sizes="144x144" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-144x144.png">
<link rel="apple-touch-icon" sizes="152x152" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-152x152.png">
<link rel="apple-touch-icon" sizes="180x180" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/apple-icon-180x180.png">
<!-- Android favicon -->
<link rel="icon" type="image/png" sizes="96x96"  href="<?= CURRENT_THEME_URL_PATH; ?>/icons/android-icon-96x96.png">
<link rel="icon" type="image/png" sizes="144x144"  href="<?= CURRENT_THEME_URL_PATH; ?>/icons/android-icon-144x144.png">
<link rel="icon" type="image/png" sizes="192x192"  href="<?= CURRENT_THEME_URL_PATH; ?>/icons/android-icon-192x192.png">
<link rel="manifest" href="<?= CURRENT_THEME_URL_PATH; ?>/icons/manifest.json">
<meta name="theme-color" content="#ffffff">

<!-- Blog RSS and JSON Feed -->
<link rel="alternate" type="application/rss+xml" title="<?= ___h(SCHLIX_SITE_NAME) ?> &raquo; RSS Feed" href="<?= SCHLIX_SITE_HTTP_URL.SCHLIX_SITE_HTTPBASE.'/'.get_application_alias('blog').'/rss' ?>" />
<link rel="alternate" type="application/json" title="<?= ___h(SCHLIX_SITE_NAME) ?> &raquo; JSON Feed" href="<?= SCHLIX_SITE_HTTP_URL.SCHLIX_SITE_HTTPBASE.'/'.get_application_alias('blog').'/jsonfeed' ?>" />
<!-- A9 OpenSearch -->
<link type="application/opensearchdescription+xml" rel="search" href="<?= SCHLIX_SITE_HTTP_URL.SCHLIX_SITE_HTTPBASE.'/'.get_application_alias('search').'/opensearchxml' ?>"/>

<?php /* Note: if you must include the Javascript at the top, use \SCHLIX\cmsPageOutput::HTMLHeader(); in header.inc.php and remove the \SCHLIX\cmsPageOutput::HTMLFooterScripts(); in footer.inc.php, and move all the contents of footer.inc.php to header.inc.php */ ?>
<?= \SCHLIX\cmsPageOutput::HTMLHeaderNonScripts(); ?>
